import { isAnyParser, Time, Timestamp, TimestampTZ, TimeTZ } from "@postgresql-typed/parsers";
export function checkValue(value, options, target, current) {
    if (Array.isArray(value))
        return value.map(v => checkValue(v, options, target, current));
    if (typeof value !== "object" || value === null)
        return value;
    const { timestamp, timestamptz, time, timetz } = options;
    if (timestamp && Timestamp.isTimestamp(value))
        return Timestamp.from(value.toDateTime(timestamp[current]).setZone(timestamp[target]).toFormat("yyyy-MM-dd HH:mm:ss"));
    if (timestamptz && TimestampTZ.isTimestampTZ(value))
        return TimestampTZ.from(value.toDateTime(timestamptz[target]).toFormat("yyyy-MM-dd HH:mm:ssZZ"));
    if (time && Time.isTime(value))
        return Time.from(value.toDateTime(time[current]).setZone(time[target]).toFormat("HH:mm:ss"));
    if (timetz && TimeTZ.isTimeTZ(value))
        return TimeTZ.from(value.toDateTime(timetz[target]).toFormat("HH:mm:ssZZ"));
    if (isAnyParser(value))
        return value;
    return Object.fromEntries(Object.entries(value).map(([key, value]) => [key, checkValue(value, options, target, current)]));
}
//# sourceMappingURL=checkValue.js.map